# Библиотека для управления магазином gdshop

Пользовательские объекты для высокоуровневой работы без привязки к слою данных. Предоставляет Python like интерфейс для работы с объектами

- Получить информацию 
- Выполнить сценарий
- Поддержка совместимости интерфейса между версиями

## Finance

- [ ] Информация о состоянии счетов
- [ ] Операций с финансами
- [ ] Статистика по финансам за периоды + Прогнозы
- [ ] Расчет и контроль бюджетов
- [ ] Сбор информации с площадок по финансам
- [ ] Генерация отчетов

## Marketing

- [ ] Статистика рекламных компаний
- [ ] Управление рекламными компаниями
- [ ] Статистика воронок
- [ ] Выгрузка информации с площадок
- [ ] Генерация отчетов

## Product
- [ ] Получение информации о продукте
- [ ] Обновление содержимого продукта
- [ ] Синхронизация информации о продуктах между платформами
- [ ] Работа с заказами
- [ ] Работа с закупками
- [ ] Выгрузка статистики
- [ ] Оценка материалов
- [ ] Работа с media
- [ ] Работа с description

## Platform
- [ ] Генерация товарных фидов


# Полезные ссылки

## Описание товарного фида

https://yandex.ru/support/partnermarket/export/yml.html
https://drive.google.com/file/d/1kkKa0KU7iNOszyC2oQSGmHNwp3sRGKFb/view